Learn R Programming

zoib (version 1.0)

joint.1z01: Jointly modelling of multiple variables taking values from [0,1] when there is a single random variable in the linear predictors of the link functions

Description

Internal function to be called by function zoib. Jointly models multiple [0,1]-bounded variables with inflation at both 0 and 1 when there is a single random variable in the linear predictors of the link functions

Usage

joint.1z01(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1, x0.1, p.x0, inflate0,
inflate1, rid, EUID, nEU, prior1, prior2, prior.beta, prior.Sigma, prec.int, 
prec.DN, lambda.L1, lambda.L2, lambda.ARD, scale.unif, scale.halft, link, n.chain)

Arguments

y
>=2 response variables taking value from [0, 1].
n
Number of rows in the data set.
q
Number of response variables.
xmu.1
Design matrix associated with the fixed effects in the linear predictor of g(mean of the beta piece), where g() is a link function.
p.xmu
Number of columns in xmu.1.
xsum.1
Design matrix associated with fixed effects in linear predictor of the log(dispersion parameter of the beta piece).
p.xsum
Number of columns in xsum.1.
x0.1
Design matrix associated with the fixed effects in the linear predictor of g(Pr(y=0)), where g() is a link function.
p.x0
Number of columns in x0.1.
x1.1
Design matrix associated with the fixed effects in the linear predictor of g(Pr(y=1)), where g() is a link function.
p.x1
Number of columns in x1.1.
inflate0
Logical vector containing the information on which response variables have inflation at 0.
inflate1
Logical vector variable containing the information on which response variables have inflation at 1.
rid
Data vector containing the information on which linear predictors have a random component.
EUID
Listing of experimental unit ID for each row of the data set.
nEU
Number of experimental units
prior1
A vector containing the prior choice for the regression coefficients in each of the 4 linear predictors of the 4 link functions.
prior2
A matrix of dimension containing the prior choice for the covariance structure of the random variables.
prior.beta
Prior choice for the regression coefficients in each of the 4 link functions (a vector of dim = 4).
prior.Sigma
Prior choice for the Covariance structure of the random variables.
prec.int
The precision in the prior distributions (diffuse normal) of the intercepts in the linear predictors.
prec.DN
The precision in the prior distributions of the regression coefficients in the linear predictors if diffuse normal prior is chosen.
lambda.ARD
The scale parameter in the prior distributions of the regression coefficients in the linear predictors if the ARD prior is chosen.
lambda.L1
The scale parameter in the prior distributions of the regression coefficients in the linear predictors if the L1-like prior is chosen.
lambda.L2
The scale parameter in the prior distributions of the regression coefficients in the linear predictors if the L2-like prior is chosen.
scale.unif
The upper bound of the uniform distribution for the standard deviation of each random variable
scale.halft
The scale parameter of the half-Cauchy distribution for the standard deviation of each random variable
link
A matrix containing the information on the choice of link function for the mean of the beta piece.
n.chain
Number of chains for the MCMC sampling.

Value

  • Internal function. Returned values are used internally

See Also

See Also as zoib